bayespy.inference.vmp.nodes.deterministic.Deterministic.move_plates
===================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.deterministic

.. automethod:: Deterministic.move_plates